==> kiosktool-trinity-14.1.5.tar.xz: kiosktool-trinity-14.1.5/kiosktool/kiosksync.h <==
/*
 *   kiosksync.h
 *
 *   Copyright (C) 2004 Waldo Bastian <bastian@kde.org>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#ifndef _KIOSKSYNC_H_
#define _KIOSKSYNC_H_

#include <tqobject.h>
#include <tqstringlist.h>

#include <kurl.h>

#include "kioskrun.h"

class TQWidget;
class KSimpleConfig;

class KioskSync : public TQObject
{
  TQ_OBJECT
  
public:  
  KioskSync( TQWidget* parent = 0, const char* name = 0);
  ~KioskSync();

  void addDir(const TQString &src, const KURL &dest);
  bool sync(bool incremental = false);
  // Returns all files found in the directories
  TQStringList listFiles();
  
signals:
  void finished();
  void status(const TQString &);
  void warning(const TQString &);
  
protected:
  void scanChangedFiles(const TQString &_dir, const TQString &prefix);
  bool syncFile(const TQString &prefix, const TQString &file, const KURL &dest);
  void addChangedDir(const TQString &dir);

private:
  struct SyncDir
  {
     SyncDir()
     { }
     
     SyncDir(const TQString &_src, const KURL &_dest) : src(_src), dest(_dest)
     { }
     
     SyncDir(const SyncDir &dir) : src(dir.src), dest(dir.dest)
     { }
  
     TQString src;
     KURL dest;
  };
  
  typedef TQValueList<SyncDir> SyncDirList;
  
  SyncDirList m_syncDirs;
  TQWidget *m_parent;
  KSimpleConfig *m_timestamps;
  TQStringList m_changedFiles;
  TQStringList m_changedDirs;
  bool m_incremental;
};

#endif

==> kiosktool-trinity_14.2.0~pre26.orig.tar.xz: kiosktool-trinity-14.2.0~pre26+75758610/kiosktool/kiosksync.h <==
/*
 *   kiosksync.h
 *
 *   Copyright (C) 2004 Waldo Bastian <bastian@kde.org>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#ifndef _KIOSKSYNC_H_
#define _KIOSKSYNC_H_

#include <tqobject.h>
#include <tqstringlist.h>

#include <kurl.h>

#include "kioskrun.h"

class TQWidget;
class TDESimpleConfig;

class KioskSync : public TQObject
{
  TQ_OBJECT
  
public:  
  KioskSync( TQWidget* parent = 0, const char* name = 0);
  ~KioskSync();

  void addDir(const TQString &src, const KURL &dest);
  bool sync(bool incremental = false);
  // Returns all files found in the directories
  TQStringList listFiles();
  
signals:
  void finished();
  void status(const TQString &);
  void warning(const TQString &);
  
protected:
  void scanChangedFiles(const TQString &_dir, const TQString &prefix);
  bool syncFile(const TQString &prefix, const TQString &file, const KURL &dest);
  void addChangedDir(const TQString &dir);

private:
  struct SyncDir
  {
     SyncDir()
     { }
     
     SyncDir(const TQString &_src, const KURL &_dest) : src(_src), dest(_dest)
     { }
     
     SyncDir(const SyncDir &dir) : src(dir.src), dest(dir.dest)
     { }
  
     TQString src;
     KURL dest;
  };
  
  typedef TQValueList<SyncDir> SyncDirList;
  
  SyncDirList m_syncDirs;
  TQWidget *m_parent;
  TDESimpleConfig *m_timestamps;
  TQStringList m_changedFiles;
  TQStringList m_changedDirs;
  bool m_incremental;
};

#endif
